summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2002-01-21 23:34:02 +0000
committerChris Lattner <sabre@nondot.org>2002-01-21 23:34:02 +0000
commit8445372636eaacad7dc34f12769a290675e351b9 (patch)
tree5967f2d36c782c640e3e8c9d7dafad3b5fcb6e55 /include
parent59b6b8e0b3e51dd899da25bd25b0793cc8229eea (diff)
downloadllvm-8445372636eaacad7dc34f12769a290675e351b9.tar.gz
llvm-8445372636eaacad7dc34f12769a290675e351b9.tar.bz2
llvm-8445372636eaacad7dc34f12769a290675e351b9.tar.xz
LowerAllocations is really a BasicBlock pass. Make it so.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@1521 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/Transforms/ChangeAllocations.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/include/llvm/Transforms/ChangeAllocations.h b/include/llvm/Transforms/ChangeAllocations.h
index 05fb133410..9adac5dd91 100644
--- a/include/llvm/Transforms/ChangeAllocations.h
+++ b/include/llvm/Transforms/ChangeAllocations.h
@@ -13,7 +13,7 @@
#include "llvm/Pass.h"
class TargetData;
-class LowerAllocations : public MethodPass {
+class LowerAllocations : public BasicBlockPass {
Method *MallocMeth; // Methods in the module we are processing
Method *FreeMeth; // Initialized by doPassInitializationVirt
@@ -26,14 +26,12 @@ public:
// doPassInitialization - For the lower allocations pass, this ensures that a
// module contains a declaration for a malloc and a free function.
//
- // This function is always successful.
- //
bool doInitialization(Module *M);
// doPerMethodWork - This method does the actual work of converting
// instructions over, assuming that the pass has already been initialized.
//
- bool runOnMethod(Method *M);
+ bool runOnBasicBlock(BasicBlock *BB);
};
#endif
@@ -26,14 +26,12 @@ public:
bool doInitialization(Module *M);
- // doPerMethodWork - This method does the actual work of converting
+ // runOnBasicBlock - This method does the actual work of converting
// instructions over, assuming that the pass has already been initialized.
//